@@ -1063,7 +1063,7 @@ class Benchmark {
         "Benchmark tasks"));
     if (Args()->show_progress) fprintf(stderr, "\n");
     return std::accumulate(errors_thread.begin(), errors_thread.end(),
-                           size_t(0));
+                           static_cast<size_t>(0));
   }
 };
 
